@@ -1,4 +1,7 @@
-VERSION = (1, 1, 0)
+# coding: utf-8
+from __future__ import unicode_literals
+
+VERSION = (1, 4, 1)
 __version__ = '.'.join(map(str, VERSION))
 
 from django_nose.runner import *
