@@ -1,7 +1,10 @@
+# coding: utf-8
 """
 Add extra options from the test runner to the ``test`` command, so that you can
 browse all the nose options from the command line.
 """
+from __future__ import unicode_literals
+
 from django.conf import settings
 from django.test.utils import get_runner
 
