@@ -1,3 +1,6 @@
+# coding: utf-8
+from __future__ import unicode_literals
+
 from django import test
 from django.conf import settings
 from django.core import cache, mail
@@ -120,6 +123,7 @@ class FastFixtureTestCase(test.TransactionTestCase):
 
         test.testcases.disable_transaction_methods()
 
+        self.client = self.client_class()
         #self._fixture_setup()
         self._urlconf_setup()
         mail.outbox = []
